@@ -10,7 +10,7 @@ from struct import pack # for network byte order
 # third party
 from mongrel2 import handler, request
 
-__version__ = '0.1.8'
+__version__ = '0.1.9'
 
 logger = logging.getLogger(__name__)
 
@@ -78,13 +78,15 @@ class Request(request.Request):
         """
         yes, this is a Request object that takes a parent version of itself to init
         """
-        super(Request, self).__init__(req.sender, req.conn_id, req.path, req.headers, req.body)
-        if hasattr(req, 'opcode'):
-            self.opcode = req.opcode
-            self.fin = req.fin
-        else:
-            self._decode_flags()
-
+        super(Request, self).__init__(
+            req.sender,
+            req.conn_id,
+            req.path,
+            req.headers,
+            req.body,
+            req.msg
+        )
+        self._decode_flags()
         self.query = req.headers.get('QUERY', '')
 
     def _decode_flags(self):
